@@ -17,6 +17,8 @@
 **  
 */
 
+// this file also contains the definition of mysum as a #define
+
 // textgenerator.h : Text Generator class &&
 
 #ifndef _TEXTGEN_H
@@ -24,6 +26,8 @@
 
 #define foo(x) (x + 1)
 
+#define mysum myfunbody 
+
 #include <iostream.h> // for cerr
 
 #include "genfun.h" /* for generating functions */
@@ -83,6 +87,7 @@ class TextDecorator : public TextGenerator {
 	if ( decorated )
 	    decorated->endTextGeneration() ;
 	endDecorate() ;
+	mysum;
     }
 
     // pure virtual functions
